@@ -84,7 +84,7 @@ The utility pkann implements an artificial neural network (ANN) to solve a super
  | bs     | bsize                | int  | 100   |Percentage of features used from available training features for each bootstrap aggregation (one size for all classes, or a different size for each class respectively | 
  | cb     | classbag             | std::string |       |output for each individual bootstrap aggregation (default is blank) | 
  | m      | mask                 | std::string |       |Only classify within specified mask (vector or raster). For raster mask, set nodata values with the option msknodata. | 
- | msknodata | msknodata            | short | 0     |mask value(s) not to consider for classification (use negative values if only these values should be taken into account). Values will be taken over in classification image. Default is 0 | 
+ | msknodata | msknodata            | short | 0     |mask value(s) not to consider for classification. Values will be taken over in classification image. Default is 0 | 
  | nodata | nodata               | unsigned short | 0     |nodata value to put where image is masked as nodata | 
  | o      | output               | std::string |       |output classification image | 
  | ot     | otype                | std::string |       |Data type for output image ({Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/CInt16/CInt32/CFloat32/CFloat64}). Empty string: inherit type from input image | 
@@ -139,11 +139,11 @@ int main(int argc, char *argv[])
   Optionpk<int> bagSize_opt("bs", "bsize", "Percentage of features used from available training features for each bootstrap aggregation (one size for all classes, or a different size for each class respectively", 100);
   Optionpk<string> classBag_opt("cb", "classbag", "output for each individual bootstrap aggregation (default is blank)"); 
   Optionpk<string> mask_opt("m", "mask", "Only classify within specified mask (vector or raster). For raster mask, set nodata values with the option msknodata.");
-  Optionpk<short> msknodata_opt("msknodata", "msknodata", "mask value(s) not to consider for classification (use negative values if only these values should be taken into account). Values will be taken over in classification image. Default is 0", 0);
+  Optionpk<short> msknodata_opt("msknodata", "msknodata", "mask value(s) not to consider for classification. Values will be taken over in classification image. Default is 0", 0);
   Optionpk<unsigned short> nodata_opt("nodata", "nodata", "nodata value to put where image is masked as nodata", 0);
   Optionpk<string> output_opt("o", "output", "output classification image"); 
   Optionpk<string>  otype_opt("ot", "otype", "Data type for output image ({Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/CInt16/CInt32/CFloat32/CFloat64}). Empty string: inherit type from input image");
-  Optionpk<string>  oformat_opt("of", "oformat", "Output image format (see also gdal_translate). Empty string: inherit from input image");
+  Optionpk<string>  oformat_opt("of", "oformat", "Output image format (see also gdal_translate).","GTiff");
   Optionpk<string> option_opt("co", "co", "Creation option for output file. Multiple options can be specified.");
   Optionpk<string> colorTable_opt("ct", "ct", "colour table in ASCII format having 5 columns: id R G B ALFA (0: transparent, 255: solid)"); 
   Optionpk<string> prob_opt("\0", "prob", "probability image. Default is no probability image"); 
@@ -155,6 +155,8 @@ int main(int argc, char *argv[])
   Optionpk<short> classvalue_opt("r", "reclass", "list of class values (use same order as in class opt)."); 
   Optionpk<short> verbose_opt("v", "verbose", "set to: 0 (results only), 1 (confusion matrix), 2 (debug)",0,2);
 
+  option_opt.setHide(1);
+  oformat_opt.setHide(1);
   band_opt.setHide(1);
   bstart_opt.setHide(1);
   bend_opt.setHide(1);
@@ -367,9 +369,9 @@ int main(int argc, char *argv[])
       try{
 	ImgReaderOgr trainingReaderBag(training_opt[ibag]);
         if(band_opt.size())
-          totalSamples=trainingReaderBag.readDataImageOgr(trainingMap,fields,band_opt,label_opt[0],tlayer_opt,verbose_opt[0]);
+          totalSamples=trainingReaderBag.readDataImageOgr(trainingMap,fields,band_opt,label_opt[0],tlayer_opt);
         else
-          totalSamples=trainingReaderBag.readDataImageOgr(trainingMap,fields,0,0,label_opt[0],tlayer_opt,verbose_opt[0]);
+          totalSamples=trainingReaderBag.readDataImageOgr(trainingMap,fields,0,0,label_opt[0],tlayer_opt);
         if(trainingMap.size()<2){
           string errorstring="Error: could not read at least two classes from training file, did you provide class labels in training sample (see option label)?";
           throw(errorstring);
@@ -789,7 +791,7 @@ int main(int argc, char *argv[])
     ImgWriterGdal probImage;
     ImgWriterGdal entropyImage;
 
-    string imageType=testImage.getImageType();
+    string imageType;//testImage.getImageType();
     if(oformat_opt.size())//default
       imageType=oformat_opt[0];
     try{
@@ -979,23 +981,23 @@ int main(int argc, char *argv[])
 	    }
 	    short theMask=0;
 	    for(short ivalue=0;ivalue<msknodata_opt.size();++ivalue){
-	      if(msknodata_opt[ivalue]>=0){//values set in msknodata_opt are invalid
+	      // if(msknodata_opt[ivalue]>=0){//values set in msknodata_opt are invalid
 		if(lineMask[colMask]==msknodata_opt[ivalue]){
 		  theMask=lineMask[colMask];
 		  masked=true;
 		  break;
 		}
-	      }
-	      else{//only values set in msknodata_opt are valid
-		if(lineMask[colMask]!=-msknodata_opt[ivalue]){
-		  theMask=lineMask[colMask];
-		  masked=true;
-		}
-		else{
-		  masked=false;
-		  break;
-		}
-	      }
+	      // }
+	      // else{//only values set in msknodata_opt are valid
+	      // 	if(lineMask[colMask]!=-msknodata_opt[ivalue]){
+	      // 	  theMask=lineMask[colMask];
+	      // 	  masked=true;
+	      // 	}
+	      // 	else{
+	      // 	  masked=false;
+	      // 	  break;
+	      // 	}
+	      // }
 	    }
 	    if(masked){
 	      if(classBag_opt.size())
