@@ -48,7 +48,7 @@ along with pktools.  If not, see <http://www.gnu.org/licenses/>.
   Options: [-ln layer]* [-c class]* [-t threshold]* [-f format] [-ft fieldType] [-lt labelType] [-polygon] [-b band]* [-r rule]
 
   Advanced options:
-       [-bndnodata band -srcnodata value]* [-tp threshold] [-test testSample] [-bn attribute] [-cn attribute] [-geo value] [-down value] [-buf value [-circ]]
+  [-sband band -eband band]* [-bndnodata band -srcnodata value]* [-tp threshold] [-test testSample] [-bn attribute] [-cn attribute] [-geo value] [-down value] [-buf value [-circ]]
 </code>
 
 \section pkextract_description Description
@@ -59,6 +59,25 @@ Instead of a vector dataset, the sample can also be a raster dataset with catego
 
 A typical usage of pkextract is to prepare a training sample for one of the classifiers implemented in pktools.
 
+\anchor pkextract_rules 
+
+Overview of the possible extraction rules:
+
+extraction rule | output features
+--------------- | ---------------
+point | Extract all pixel values covered by the polygon (option -polygon not set) or extract a pixel on the surface option (-polygon set).
+centroid | Extract pixel value at the centroid of the polygon.
+mean | Extract average of all pixel values within the polygon.
+stdev | Extract standard deviation of all pixel values within the polygon.
+median | Extract median of all pixel values within the polygon.
+min | Extract minimum value of all pixels within the polygon.
+max | Extract maximum value of all pixels within the polygon.
+sum | Extract sum of the values of all pixels within the polygon.
+mode | Extract the mode of classes within the polygon (classes must be set with the option class).
+proportion | Extract proportion of class(es) within the polygon (classes must be set with the option class).
+count | Extract count of class(es) within the polygon (classes must be set with the option class).
+percentile | Extract percentile as defined by option perc (e.g, 95th percentile of values covered by polygon).
+
 \section pkextract_options Options
  - use either `-short` or `--long` options (both `--long=value` and `--long value` are supported)
  - short option `-h` shows basic options only, long option `--help` shows all options
@@ -70,7 +89,7 @@ A typical usage of pkextract is to prepare a training sample for one of the clas
  | rand   | random               | unsigned int |       |Create simple random sample of points. Provide number of points to generate | 
  | grid   | grid                 | double |       |Create systematic grid of points. Provide cell grid size (in projected units, e.g,. m) | 
  | o      | output               | std::string |       |Output sample dataset | 
- | c      | class                | int  |       |Class(es) to extract from input sample image. Leave empty to extract all valid data pixels from sample dataset. Make sure to set classes if rule is set to mode or proportion | 
+ | c      | class                | int  |       |Class(es) to extract from input sample image. Leave empty to extract all valid data pixels from sample dataset. Make sure to set classes if rule is set to mode, proportion or count | 
  | t      | threshold            | float | 100   |Probability threshold for selecting samples (randomly). Provide probability in percentage (>0) or absolute (<0). Use a single threshold for vector sample datasets. If using raster land cover maps as a sample dataset, you can provide a threshold value for each class (e.g. -t 80 -t 60). Use value 100 to select all pixels for selected class(es) | 
  | perc   | perc                 | double | 95    |Percentile value used for rule percentile | 
  | f      | f                    | std::string | SQLite |Output sample dataset format | 
@@ -78,7 +97,9 @@ A typical usage of pkextract is to prepare a training sample for one of the clas
  | lt     | ltype                | std::string | Integer |Label type: In16 or String | 
  | polygon | polygon              | bool | false |Create OGRPolygon as geometry instead of OGRPoint. | 
  | b      | band                 | int  |       |Band index(es) to extract (0 based). Leave empty to use all bands | 
- | r      | rule                 | std::string | centroid |Rule how to report image information per feature (only for vector sample). point (value at each point or at centroid if polygon), centroid, mean, stdev, median, proportion, min, max, mode, sum, percentile. | 
+ | sband  | startband            | unsigned short |      |Start band sequence number | 
+ | eband  | endband              | unsigned short |      |End band sequence number   | 
+ | r      | rule                 | std::string | centroid |Rule how to report image information per feature (only for vector sample). point (value at each point or at centroid if polygon), centroid, mean, stdev, median, proportion, count, min, max, mode, sum, percentile. | 
  | bndnodata | bndnodata            | int  | 0     |Band(s) in input image to check if pixel is valid (used for srcnodata) | 
  | srcnodata | srcnodata            | double |       |Invalid value(s) for input image | 
  | tp     | thresholdPolygon     | float |       |(absolute) threshold for selecting samples in each polygon | 
@@ -99,7 +120,7 @@ Some examples how to use pkextract can be found \ref examples_pkextract "here"
 **/
 
 namespace rule{
-  enum RULE_TYPE {point=0, mean=1, proportion=2, custom=3, min=4, max=5, mode=6, centroid=7, sum=8, median=9, stdev=10, percentile=11};
+  enum RULE_TYPE {point=0, mean=1, proportion=2, custom=3, min=4, max=5, mode=6, centroid=7, sum=8, median=9, stdev=10, percentile=11, count=12};
 }
 
 using namespace std;
@@ -112,7 +133,7 @@ int main(int argc, char *argv[])
   Optionpk<unsigned int> random_opt("rand", "random", "Create simple random sample of points. Provide number of points to generate");
   Optionpk<double> grid_opt("grid", "grid", "Create systematic grid of points. Provide cell grid size (in projected units, e.g,. m)");
   Optionpk<string> output_opt("o", "output", "Output sample dataset");
-  Optionpk<int> class_opt("c", "class", "Class(es) to extract from input sample image. Leave empty to extract all valid data pixels from sample dataset. Make sure to set classes if rule is set to mode or proportion");
+  Optionpk<int> class_opt("c", "class", "Class(es) to extract from input sample image. Leave empty to extract all valid data pixels from sample dataset. Make sure to set classes if rule is set to mode, proportion or count");
   Optionpk<float> threshold_opt("t", "threshold", "Probability threshold for selecting samples (randomly). Provide probability in percentage (>0) or absolute (<0). Use a single threshold for vector sample datasets. If using raster land cover maps as a sample dataset, you can provide a threshold value for each class (e.g. -t 80 -t 60). Use value 100 to select all pixels for selected class(es)", 100);
   Optionpk<double> percentile_opt("perc","perc","Percentile value used for rule percentile",95);
   Optionpk<string> ogrformat_opt("f", "f", "Output sample dataset format","SQLite");
@@ -120,7 +141,9 @@ int main(int argc, char *argv[])
   Optionpk<string> ltype_opt("lt", "ltype", "Label type: In16 or String", "Integer");
   Optionpk<bool> polygon_opt("polygon", "polygon", "Create OGRPolygon as geometry instead of OGRPoint.", false);
   Optionpk<int> band_opt("b", "band", "Band index(es) to extract (0 based). Leave empty to use all bands");
-  Optionpk<string> rule_opt("r", "rule", "Rule how to report image information per feature (only for vector sample). point (value at each point or at centroid if polygon), centroid, mean, stdev, median, proportion, min, max, mode, sum, percentile.", "centroid");
+  Optionpk<unsigned short> bstart_opt("sband", "startband", "Start band sequence number"); 
+  Optionpk<unsigned short> bend_opt("eband", "endband", "End band sequence number"); 
+  Optionpk<string> rule_opt("r", "rule", "Rule how to report image information per feature (only for vector sample). point (value at each point or at centroid if polygon), centroid, mean, stdev, median, proportion, count, min, max, mode, sum, percentile.", "centroid");
   Optionpk<double> srcnodata_opt("srcnodata", "srcnodata", "Invalid value(s) for input image");
   Optionpk<int> bndnodata_opt("bndnodata", "bndnodata", "Band(s) in input image to check if pixel is valid (used for srcnodata)", 0);
   Optionpk<float> polythreshold_opt("tp", "thresholdPolygon", "(absolute) threshold for selecting samples in each polygon");
@@ -133,6 +156,8 @@ int main(int argc, char *argv[])
   Optionpk<bool> disc_opt("circ", "circular", "Use a circular disc kernel buffer (for vector point sample datasets only, use in combination with buffer option)", false);
   Optionpk<short> verbose_opt("v", "verbose", "Verbose mode if > 0", 0,2);
 
+  bstart_opt.setHide(1);
+  bend_opt.setHide(1);
   bndnodata_opt.setHide(1);
   srcnodata_opt.setHide(1);
   polythreshold_opt.setHide(1);
@@ -161,6 +186,8 @@ int main(int argc, char *argv[])
     ltype_opt.retrieveOption(argc,argv);
     polygon_opt.retrieveOption(argc,argv);
     band_opt.retrieveOption(argc,argv);
+    bstart_opt.retrieveOption(argc,argv);
+    bend_opt.retrieveOption(argc,argv);
     rule_opt.retrieveOption(argc,argv);
     bndnodata_opt.retrieveOption(argc,argv);
     srcnodata_opt.retrieveOption(argc,argv);
@@ -196,6 +223,7 @@ int main(int argc, char *argv[])
   ruleMap["stdev"]=rule::stdev;
   ruleMap["median"]=rule::median;
   ruleMap["proportion"]=rule::proportion;
+  ruleMap["count"]=rule::count;
   ruleMap["min"]=rule::min;
   ruleMap["max"]=rule::max;
   ruleMap["custom"]=rule::custom;
@@ -241,6 +269,29 @@ int main(int argc, char *argv[])
     std::cout << errorstring << std::endl;
     exit(0);
   }
+
+  //convert start and end band options to vector of band indexes
+  try{
+    if(bstart_opt.size()){
+      if(bend_opt.size()!=bstart_opt.size()){
+	string errorstring="Error: options for start and end band indexes must be provided as pairs, missing end band";
+	throw(errorstring);
+      }
+      band_opt.clear();
+      for(int ipair=0;ipair<bstart_opt.size();++ipair){
+	if(bend_opt[ipair]<=bstart_opt[ipair]){
+	  string errorstring="Error: index for end band must be smaller then start band";
+	  throw(errorstring);
+	}
+	for(int iband=bstart_opt[ipair];iband<=bend_opt[ipair];++iband)
+	  band_opt.push_back(iband);
+      }
+    }
+  }
+  catch(string error){
+    cerr << error << std::endl;
+    exit(1);
+  }
   
   int nband=(band_opt.size()) ? band_opt.size() : imgReader.nrOfBand();
 
@@ -806,17 +857,44 @@ int main(int argc, char *argv[])
       std::cout << "creating image sample writer " << output_opt[0] << std::endl;
     ImgWriterOgr ogrWriter;
     ImgWriterOgr ogrTestWriter;
-    ogrWriter.open(output_opt[0],ogrformat_opt[0]);
-    if(test_opt.size()){
-      if(verbose_opt[0]>1)
-	std::cout << "creating image test writer " << test_opt[0] << std::endl;
-      try{
+    try{
+      ogrWriter.open(output_opt[0],ogrformat_opt[0]);
+      if(test_opt.size()){
+	if(verbose_opt[0]>1)
+	  std::cout << "creating image test writer " << test_opt[0] << std::endl;
 	ogrTestWriter.open(test_opt[0],ogrformat_opt[0]);
       }
-      catch(string errorString){
-	cerr << errorString << endl;
+
+      //if class_opt not set, get number of classes from input image for these rules
+      switch(ruleMap[rule_opt[0]]){
+      case(rule::proportion):
+      case(rule::count):
+      case(rule::custom):
+      case(rule::mode):{
+	if(class_opt.empty()){
+	  int theBand=0;
+	  double minValue=0;
+	  double maxValue=0;
+	  if(band_opt.size())
+	    theBand=band_opt[0];
+	  imgReader.getMinMax(minValue,maxValue,theBand);
+	  int nclass=maxValue-minValue+1;
+	  if(nclass<0&&nclass<256){
+	    string errorString="Could not automatically define classes, please set class option";
+	    throw(errorString);
+	  }
+	  for(int iclass=minValue;iclass<=maxValue;++iclass)
+	    class_opt.push_back(iclass);
+	}
+	break;
+      }
       }
     }
+    catch(string errorString){
+      cerr << errorString << endl;
+      exit(1);
+    }
+    
     //support multiple layers
     int nlayerRead=sampleReaderOgr.getDataSource()->GetLayerCount();
     int ilayerWrite=0;
@@ -872,7 +950,8 @@ int main(int argc, char *argv[])
 
       if(class_opt.size()){
 	switch(ruleMap[rule_opt[0]]){
-	case(rule::proportion):{//proportion for each class
+	case(rule::proportion)://proportion for each class
+	case(rule::count):{//count for each class
 	  for(int iclass=0;iclass<class_opt.size();++iclass){
 	    ostringstream cs;
 	    cs << class_opt[iclass];
@@ -1076,15 +1155,6 @@ int main(int argc, char *argv[])
 	    vector< Vector2d<double> > readValues(nband);
 	    for(int iband=0;iband<nband;++iband){
 	      int theBand=(band_opt.size()) ? band_opt[iband] : iband;
-	      //test
-	      assert(uli>=0);
-	      assert(uli<imgReader.nrOfCol());	      
-	      assert(lri>=0);
-	      assert(lri<imgReader.nrOfCol());	      
-	      assert(ulj>=0);
-	      assert(ulj<imgReader.nrOfRow());	      
-	      assert(lrj>=0);
-	      assert(lrj<imgReader.nrOfRow());	      
 	      imgReader.readDataBlock(readValues[iband],GDT_Float64,uli,lri,ulj,lrj,theBand);
 	    }
 
@@ -1373,10 +1443,11 @@ int main(int argc, char *argv[])
 		}
 	      }
 	      else{//class_opt is set
-		if(ruleMap[rule_opt[0]]==rule::proportion){
+		if(ruleMap[rule_opt[0]]==rule::proportion||ruleMap[rule_opt[0]]==rule::count){
 		  if(verbose_opt[0])
 		    std::cout << "number of points in polygon: " << nPointWindow << std::endl;
-		  stat.normalize_pct(windowClassValues);
+		  if(ruleMap[rule_opt[0]]==rule::proportion)
+		    stat.normalize_pct(windowClassValues);
 		  for(int index=0;index<windowClassValues.size();++index){
 		    double theValue=windowClassValues[index];
 		    ostringstream fs;
@@ -1488,9 +1559,10 @@ int main(int argc, char *argv[])
 	      std::cout << "get point on polygon" << std::endl;
 	    if(ruleMap[rule_opt[0]]==rule::centroid)
 	      readPolygon.Centroid(&writeCentroidPoint);
-	    else
-	      readPolygon.PointOnSurface(&writeCentroidPoint);
-
+	    else if(readPolygon.PointOnSurface(&writeCentroidPoint)!=OGRERR_NONE){
+	      // cerr << "function PointOnSurface failed, trying centroid instead" << endl;
+	      readPolygon.Centroid(&writeCentroidPoint);
+	    }
 	    double ulx,uly,lrx,lry;
 	    double uli,ulj,lri,lrj;
 	    if((polygon_opt[0]&&ruleMap[rule_opt[0]]==rule::point)||(ruleMap[rule_opt[0]]==rule::centroid)){
@@ -1579,15 +1651,6 @@ int main(int argc, char *argv[])
 	    vector< Vector2d<double> > readValues(nband);
 	    for(int iband=0;iband<nband;++iband){
 	      int theBand=(band_opt.size()) ? band_opt[iband] : iband;
-	      //test
-	      assert(uli>=0);
-	      assert(uli<imgReader.nrOfCol());	      
-	      assert(lri>=0);
-	      assert(lri<imgReader.nrOfCol());	      
-	      assert(ulj>=0);
-	      assert(ulj<imgReader.nrOfRow());	      
-	      assert(lrj>=0);
-	      assert(lrj<imgReader.nrOfRow());	      
 	      imgReader.readDataBlock(readValues[iband],GDT_Float64,uli,lri,ulj,lrj,theBand);
 	    }
 
@@ -1605,7 +1668,6 @@ int main(int argc, char *argv[])
 		imgReader.image2geo(i,j,theX,theY);
 		thePoint.setX(theX);
 		thePoint.setY(theY);
-		
 		if(ruleMap[rule_opt[0]]!=rule::centroid&&!readPolygon.Contains(&thePoint))
 		  continue;
 
@@ -1654,7 +1716,6 @@ int main(int argc, char *argv[])
 		    //test
 		    writePointFeature->SetGeometry(&thePoint);
 		    assert(wkbFlatten(writePointFeature->GetGeometryRef()->getGeometryType()) == wkbPoint);
-		    //test
 		    // OGRGeometry *updateGeometry;
 		    // updateGeometry = writePointFeature->GetGeometryRef();
 		    // OGRPoint *poPoint = (OGRPoint *) updateGeometry;
@@ -1671,13 +1732,7 @@ int main(int argc, char *argv[])
 		}
 		else{
 		  for(int iband=0;iband<nband;++iband){
-		    int theBand=(band_opt.size()) ? band_opt[iband] : iband;
-		    assert(j-ulj>=0);
-		    assert(j-ulj<readValues[iband].size());
-		    assert(i-uli>=0);
-		    assert(i-uli<((readValues[iband])[j-ulj]).size());
 		    double value=((readValues[iband])[j-ulj])[i-uli];
-		    // imgReader.readData(value,GDT_Float64,i,j,theBand);
 		    if(verbose_opt[0]>1)
 		      std::cout << ": " << value << std::endl;
 		    if(polygon_opt[0]||ruleMap[rule_opt[0]]!=rule::point)
@@ -1753,16 +1808,10 @@ int main(int argc, char *argv[])
 		//create feature
 		if(verbose_opt[0]>1)
 		  std::cout << "copying fields from polygons " << std::endl;
-		//test
-		//writeCentroidFeature->SetGeometry(&writeCentroidPoint);
 		if(writeCentroidFeature->SetFrom(readFeature)!= OGRERR_NONE)
 		  cerr << "writing feature failed" << std::endl;
-		//test
 		writeCentroidFeature->SetGeometry(&writeCentroidPoint);
 		assert(wkbFlatten(writeCentroidFeature->GetGeometryRef()->getGeometryType()) == wkbPoint );
-		// OGRGeometry *updateGeometry;
-		// updateGeometry = writeCentroidFeature->GetGeometryRef();
-		// assert(wkbFlatten(updateGeometry->getGeometryType()) == wkbPoint );
 		if(verbose_opt[0]>1)
 		  std::cout << "write feature has " << writeCentroidFeature->GetFieldCount() << " fields" << std::endl;
 	      }
@@ -1865,10 +1914,11 @@ int main(int argc, char *argv[])
 		}
 	      }
 	      else{//class_opt is set
-		if(ruleMap[rule_opt[0]]==rule::proportion){
+		if(ruleMap[rule_opt[0]]==rule::proportion||ruleMap[rule_opt[0]]==rule::count){
 		  if(verbose_opt[0])
 		    std::cout << "number of points in polygon: " << nPointPolygon << std::endl;
-		  stat.normalize_pct(polyClassValues);
+		  if(ruleMap[rule_opt[0]]==rule::proportion)
+		    stat.normalize_pct(polyClassValues);
 		  for(int index=0;index<polyClassValues.size();++index){
 		    double theValue=polyClassValues[index];
 		    ostringstream fs;
@@ -1977,7 +2027,6 @@ int main(int argc, char *argv[])
 
 	    if(verbose_opt[0]>1)
 	      std::cout << "get centroid point from polygon" << std::endl;
-
 	    readPolygon.Centroid(&writeCentroidPoint);
 
 	    double ulx,uly,lrx,lry;
@@ -2066,15 +2115,6 @@ int main(int argc, char *argv[])
 	    vector< Vector2d<double> > readValues(nband);
 	    for(int iband=0;iband<nband;++iband){
 	      int theBand=(band_opt.size()) ? band_opt[iband] : iband;
-	      //test
-	      assert(uli>=0);
-	      assert(uli<imgReader.nrOfCol());	      
-	      assert(lri>=0);
-	      assert(lri<imgReader.nrOfCol());	      
-	      assert(ulj>=0);
-	      assert(ulj<imgReader.nrOfRow());	      
-	      assert(lrj>=0);
-	      assert(lrj<imgReader.nrOfRow());	      
 	      imgReader.readDataBlock(readValues[iband],GDT_Float64,uli,lri,ulj,lrj,theBand);
 	    }
 
@@ -2134,10 +2174,10 @@ int main(int argc, char *argv[])
 			writePointFeature = OGRFeature::CreateFeature(writeLayer->GetLayerDefn());
 		      if(verbose_opt[0]>1)
 			std::cout << "copying fields from polygons " << std::endl;
-		      //test
-		      // writePointFeature->SetGeometry(&thePoint);
 		      if(writePointFeature->SetFrom(readFeature)!= OGRERR_NONE)
 			cerr << "writing feature failed" << std::endl;
+		      if(verbose_opt[0]>1)
+			std::cout << "set geometry as point " << std::endl;
 		      //test
 		      writePointFeature->SetGeometry(&thePoint);
 		      assert(wkbFlatten(writePointFeature->GetGeometryRef()->getGeometryType()) == wkbPoint);
@@ -2157,13 +2197,7 @@ int main(int argc, char *argv[])
 		  }
 		  else{
 		    for(int iband=0;iband<nband;++iband){
-		      //test
-		      assert(j-ulj>=0);
-		      assert(j-ulj<readValues[iband].size());
-		      assert(i-uli>=0);
-		      assert(i-uli<((readValues[iband])[j-ulj]).size());
 		      double value=((readValues[iband])[j-ulj])[i-uli];
-		      // imgReader.readData(value,GDT_Float64,i,j,theBand);
 		      if(verbose_opt[0]>1)
 			std::cout << ": " << value << std::endl;
 		      if(polygon_opt[0]||ruleMap[rule_opt[0]]!=rule::point)
@@ -2179,17 +2213,6 @@ int main(int argc, char *argv[])
 			case OFTString:
 			  writePointFeature->SetField(fieldname_opt[iband].c_str(),type2string<double>(value).c_str());
 			  break;
-			  // case OFTRealList:{
-			  //   int fieldIndex=writePointFeature->GetFieldIndex(fieldname_opt[iband].c_str());
-			  //   int nCount;
-			  //   const double *theList;
-			  //   theList=writePointFeature->GetFieldAsDoubleList(fieldIndex,&nCount);
-			  //   vector<double> vectorList(nCount+1);
-			  //   for(int index=0;index<nCount;++index)
-			  // 	vectorList[nCount]=value;
-			  //   writePointFeature->SetField(fieldIndex,vectorList.size(),&(vectorList[0]));
-			  //   break;
-			  // }
 			default://not supported
 			  assert(0);
 			  break;
@@ -2251,16 +2274,10 @@ int main(int argc, char *argv[])
 		//create feature
 		if(verbose_opt[0]>1)
 		  std::cout << "copying fields from polygons " << std::endl;
-		//test
-		// writeCentroidFeature->SetGeometry(&writeCentroidPoint);
 		if(writeCentroidFeature->SetFrom(readFeature)!= OGRERR_NONE)
 		  cerr << "writing feature failed" << std::endl;
 		writeCentroidFeature->SetGeometry(&writeCentroidPoint);
 		assert(wkbFlatten(writeCentroidFeature->GetGeometryRef()->getGeometryType()) == wkbPoint);
-		//test
-		// OGRGeometry *updateGeometry;
-		// updateGeometry = writeCentroidFeature->GetGeometryRef();
-		// assert(wkbFlatten(updateGeometry->getGeometryType()) == wkbPoint );
 		if(verbose_opt[0]>1)
 		  std::cout << "write feature has " << writeCentroidFeature->GetFieldCount() << " fields" << std::endl;
 	      }
@@ -2363,10 +2380,11 @@ int main(int argc, char *argv[])
 		}
 	      }
 	      else{//class_opt is set
-		if(ruleMap[rule_opt[0]]==rule::proportion){
+		if(ruleMap[rule_opt[0]]==rule::proportion||ruleMap[rule_opt[0]]==rule::count){
 		  if(verbose_opt[0])
 		    std::cout << "number of points in polygon: " << nPointPolygon << std::endl;
-		  stat.normalize_pct(polyClassValues);
+		  if(ruleMap[rule_opt[0]]==rule::proportion)
+		    stat.normalize_pct(polyClassValues);
 		  for(int index=0;index<polyClassValues.size();++index){
 		    double theValue=polyClassValues[index];
 		    ostringstream fs;
@@ -2472,7 +2490,10 @@ int main(int argc, char *argv[])
 	    throw(oss.str());
 	  }
 	  ++ifeature;
-	  progress=static_cast<float>(ifeature+1)/nfeature;
+	  if(threshold_opt[0]>0)
+	    progress=(100.0/threshold_opt[0])*static_cast<float>(ifeature+1)/nfeature;
+	  else
+	    progress=static_cast<float>(ifeature+1)/(-threshold_opt[0]);
 	  pfnProgress(progress,pszMessage,pProgressArg);
 	}
 	catch(std::string e){
@@ -2491,6 +2512,7 @@ int main(int argc, char *argv[])
       pfnProgress(progress,pszMessage,pProgressArg);
       ++ilayerWrite;
     }//for ilayer
+    sampleReaderOgr.close();
     ogrWriter.close();
     if(test_opt.size())
       ogrTestWriter.close();
