@@ -20,7 +20,11 @@ along with pktools.  If not, see <http://www.gnu.org/licenses/>.
 #include <iostream>
 #include <iomanip>
 #include <time.h>
+#include <algorithm>
 #include "ogr_spatialref.h"
+extern "C" {
+#include "gdal_alg.h"
+}
 #include "ImgWriterGdal.h"
 
 #ifdef HAVE_CONFIG_H
@@ -605,3 +609,46 @@ bool ImgWriterGdal::writeData(void* pdata, const GDALDataType& dataType, int ban
   poBand->RasterIO(GF_Write,0,0,nrOfCol(),nrOfRow(),pdata,nrOfCol(),nrOfRow(),dataType,0,0);
   return true;
 }  
+
+void ImgWriterGdal::rasterizeOgr(ImgReaderOgr& ogrReader, const std::vector<double>& burnValues, const std::vector<std::string>& layernames ){
+  std::vector<int> bands;
+  std::vector<double> burnBands;//burn values for all bands in a single layer
+  std::vector<double> burnLayers;//burn values for all bands and all layers
+  if(burnValues.empty()){
+    std::string errorString="Error: burn values not provided";
+    throw(errorString);
+  }
+  burnBands=burnValues;
+  while(burnBands.size()<nrOfBand())
+    burnBands.push_back(burnValues[0]);
+  for(int iband=0;iband<nrOfBand();++iband)
+    bands.push_back(iband+1);
+  std::vector<OGRLayerH> layers;
+  int nlayer=0;
+  for(int ilayer=0;ilayer<ogrReader.getLayerCount();++ilayer){
+    std::string currentLayername=ogrReader.getLayer(ilayer)->GetName();
+    if(layernames.size())
+      if(find(layernames.begin(),layernames.end(),currentLayername)==layernames.end())
+	continue;
+    std::cout << "processing layer " << currentLayername << std::endl;
+    layers.push_back((OGRLayerH)ogrReader.getLayer(ilayer));
+    ++nlayer;
+    for(int iband=0;iband<nrOfBand();++iband)
+      burnLayers.insert(burnLayers.end(),burnBands.begin(),burnBands.end());
+  }
+  void *pTransformArg;
+  char **papszOptions;
+  double dfComplete=0.0;
+  const char* pszMessage;
+  void* pProgressArg=NULL;
+  GDALProgressFunc pfnProgress=GDALTermProgress;
+  pfnProgress(dfComplete,pszMessage,pProgressArg);
+  if(GDALRasterizeLayers( (GDALDatasetH)m_gds,nrOfBand(),&(bands[0]),layers.size(),&(layers[0]),NULL,pTransformArg,&(burnLayers[0]),papszOptions,pfnProgress,pProgressArg)!=CE_None){
+    std::cerr << CPLGetLastErrorMsg() << std::endl;
+    exit(1);
+  }
+  else{
+    dfComplete=1.0;
+    pfnProgress(dfComplete,pszMessage,pProgressArg);
+  }
+}
